Crate rocket_mongo_file_center_raw_response

Crate rocket_mongo_file_center_raw_response 

File Center Raw Response on MongoDB for Rocket Framework

This crate provides response struct used for responding raw data from the File Center on MongoDB with Etag cache optionally.

See examples.

Re-exports

pub extern crate mongo_file_center;

Structs

EntityTag
An entity tag, defined in RFC7232.
EtagIfNoneMatch
The request guard used for getting if-none-match header.
FileCenterRawResponse
The response struct used for responding raw data from the File Center on MongoDB with Etag cache.