File Center Raw Response on MongoDB for Rocket Framework
This crate provides response struct used for responding raw data from the File Center on MongoDB with Etag cache optionally.
See examples.
Re-exports
pub extern crate mongo_file_center;
Structs
- Entity
Tag - An entity tag, defined in RFC7232.
- Etag
IfNone Match - The request guard used for getting
if-none-matchheader. - File
Center RawResponse - The response struct used for responding raw data from the File Center on MongoDB with Etag cache.